package com.ruoyi.project.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.plant.mapper.TMtdItemMapper;
import com.ruoyi.project.plant.domain.TMtdItem;
import com.ruoyi.project.plant.service.ITMtdItemService;

import javax.annotation.Resource;

/**
 * 调度会议详情Service业务层处理
 *
 * @author ssy
 * @date 2023-11-15
 */
@Service
public class TMtdItemServiceImpl implements ITMtdItemService
{
    @Resource
    private TMtdItemMapper tMtdItemMapper;

    /**
     * 查询调度会议详情
     *
     * @param id 调度会议详情ID
     * @return 调度会议详情
     */
    @Override
    public TMtdItem selectTMtdItemById(Long id)
    {
        return tMtdItemMapper.selectTMtdItemById(id);
    }

    /**
     * 查询调度会议详情列表
     *
     * @param tMtdItem 调度会议详情
     * @return 调度会议详情
     */
    @Override
    public List<TMtdItem> selectTMtdItemList(TMtdItem tMtdItem)
    {
        return tMtdItemMapper.selectTMtdItemList(tMtdItem);
    }

    /**
     * 新增调度会议详情
     *
     * @param tMtdItem 调度会议详情
     * @return 结果
     */
    @Override
    public int insertTMtdItem(TMtdItem tMtdItem)
    {
        return tMtdItemMapper.insertTMtdItem(tMtdItem);
    }

    /**
     * 修改调度会议详情
     *
     * @param tMtdItem 调度会议详情
     * @return 结果
     */
    @Override
    public int updateTMtdItem(TMtdItem tMtdItem)
    {
        return tMtdItemMapper.updateTMtdItem(tMtdItem);
    }

    /**
     * 批量删除调度会议详情
     *
     * @param ids 需要删除的调度会议详情ID
     * @return 结果
     */
    @Override
    public int deleteTMtdItemByIds(Long[] ids)
    {
        return tMtdItemMapper.deleteTMtdItemByIds(ids);
    }

    /**
     * 删除调度会议详情信息
     *
     * @param id 调度会议详情ID
     * @return 结果
     */
    @Override
    public int deleteTMtdItemById(Long id)
    {
        return tMtdItemMapper.deleteTMtdItemById(id);
    }
}
